@@ -8,6 +8,7 @@ import time
 from pycromanager.core import serialize_array, deserialize_array, Bridge
 from pycromanager.data import Dataset
 import warnings
+import os.path
 
 ### These functions outside class to prevent problems with pickling when running them in differnet process
 
@@ -16,12 +17,16 @@ def _event_sending_fn(event_port, event_queue, debug=False):
     event_socket = bridge._connect_push(event_port)
     while True:
         events = event_queue.get(block=True)
+        if debug:
+            print('got event(s): ' + events)
         if events is None:
             # Poison, time to shut down
             event_socket.send({'events': [{'special': 'acquisition-end'}]})
             event_socket.close()
             return
         event_socket.send({'events': events if type(events) == list else [events]})
+        if debug:
+            print('sent events')
 
 def _acq_hook_startup_fn(pull_port, push_port, hook_connected_evt, event_queue, hook_fn, debug):
     bridge = Bridge(debug=debug)
@@ -154,6 +159,12 @@ class Acquisition(object):
         self._debug = debug
         self._dataset = None
 
+        if directory is not None:
+            # Expend ~ in path
+            directory = os.path.expanduser(directory)
+            # If path is relative, retain knowledge of the current working directory
+            directory = os.path.abspath(directory)
+
         if magellan_acq_index is not None:
             magellan_api = self.bridge.get_magellan()
             self._remote_acq = magellan_api.create_acquisition(magellan_acq_index)
